"use client"

import { useEffect, useState } from "react"
import { useRouter, useSearchParams } from "next/navigation"
import { CheckCircle } from "lucide-react"
import { Button } from "@/components/ui/button"
import Link from "next/link"

export default function PaymentSuccessPage() {
  const router = useRouter()
  const searchParams = useSearchParams()
  const sessionId = searchParams.get("session_id")
  const [isVerifying, setIsVerifying] = useState(true)
  const [isSuccess, setIsSuccess] = useState(false)
  const [error, setError] = useState<string | null>(null)

  useEffect(() => {
    async function verifyPayment() {
      if (!sessionId) {
        setError("Session ID not found")
        setIsVerifying(false)
        return
      }

      try {
        const response = await fetch(`/api/payments/verify?session_id=${sessionId}`)
        const data = await response.json()

        if (response.ok) {
          setIsSuccess(true)
        } else {
          setError(data.error || "Failed to verify payment")
        }
      } catch (error) {
        console.error("Error verifying payment:", error)
        setError("An error occurred while verifying your payment")
      } finally {
        setIsVerifying(false)
      }
    }

    verifyPayment()
  }, [sessionId])

  return (
    <div className="min-h-screen bg-gray-50 flex flex-col items-center justify-center p-4">
      <div className="max-w-md w-full bg-white rounded-lg shadow-lg p-8">
        {isVerifying ? (
          <div className="text-center">
            <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-blue-500 mx-auto mb-4"></div>
            <h2 className="text-xl font-bold mb-2">Vérification du paiement</h2>
            <p className="text-gray-600">Veuillez patienter pendant que nous vérifions votre paiement...</p>
          </div>
        ) : isSuccess ? (
          <div className="text-center">
            <div className="w-16 h-16 bg-green-100 rounded-full flex items-center justify-center mx-auto mb-4">
              <CheckCircle className="h-10 w-10 text-green-500" />
            </div>
            <h2 className="text-2xl font-bold mb-2">Paiement réussi !</h2>
            <p className="text-gray-600 mb-6">
              Votre abonnement a été activé avec succès. Vous pouvez maintenant accéder à toutes les fonctionnalités de
              votre plan.
            </p>
            <div className="space-y-3">
              <Button asChild className="w-full bg-route-blue hover:bg-route-blue/90">
                <Link href="/login">Se connecter</Link>
              </Button>
              <Button asChild variant="outline" className="w-full">
                <Link href="/">Retour à l'accueil</Link>
              </Button>
            </div>
          </div>
        ) : (
          <div className="text-center">
            <div className="w-16 h-16 bg-red-100 rounded-full flex items-center justify-center mx-auto mb-4">
              <svg
                xmlns="http://www.w3.org/2000/svg"
                className="h-10 w-10 text-red-500"
                fill="none"
                viewBox="0 0 24 24"
                stroke="currentColor"
              >
                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
              </svg>
            </div>
            <h2 className="text-2xl font-bold mb-2">Erreur de vérification</h2>
            <p className="text-gray-600 mb-6">
              {error || "Une erreur est survenue lors de la vérification de votre paiement."}
            </p>
            <div className="space-y-3">
              <Button asChild className="w-full bg-route-blue hover:bg-route-blue/90">
                <Link href="/subscription">Réessayer</Link>
              </Button>
              <Button asChild variant="outline" className="w-full">
                <Link href="/">Retour à l'accueil</Link>
              </Button>
            </div>
          </div>
        )}
      </div>
    </div>
  )
}
